/**
 * Enum representing the available Chromium routes for conversion.
 * @enum {string}
 */
export declare enum ChromiumRoute {
    URL = "url",
    HTML = "html",
    MARKDOWN = "markdown"
}
/**
 * Enum representing the available routes for the PDF engine.
 * @enum {string}
 */
declare enum PdfEngineRoute {
    MERGE = "merge",
    READ_METADATA = "metadata/read",
    WRITE_METADATA = "metadata/write"
}
/**
 * Enum representing the available routes for LibreOffice.
 * @enum {string}
 */
declare enum LibreOfficeRoute {
    CONVERT = "convert"
}
/**
 * Class providing constants and routes for interacting with the Gotenberg service and related engines.
 */
export declare class Chromiumly {
    /**
     * The Gotenberg service endpoint.
     * @type {string}
     */
    private static gotenbergEndpoint;
    /**
     * The username for basic authentication with the Gotenberg service.
     * @type {string | undefined}
     */
    private static gotenbergApiBasicAuthUsername;
    /**
     * The password for basic authentication with the Gotenberg service.
     * @type {string | undefined}
     */
    private static gotenbergApiBasicAuthPassword;
    /**
     * The path for Chromium-related conversions.
     * @type {string}
     */
    static readonly CHROMIUM_CONVERT_PATH = "forms/chromium/convert";
    /**
     * The path for Chromium-related screenshots.
     * @type {string}
     */
    static readonly CHROMIUM_SCREENSHOT_PATH = "forms/chromium/screenshot";
    /**
     * The path for PDF engine-related operations.
     * @type {string}
     */
    static readonly PDF_ENGINES_PATH = "forms/pdfengines";
    /**
     * The path for LibreOffice-related conversions.
     * @type {string}
     */
    static readonly LIBRE_OFFICE_PATH = "forms/libreoffice";
    /**
     * Routes for Chromium conversions.
     * @type {Object}
     */
    static readonly CHROMIUM_ROUTES: {
        url: ChromiumRoute;
        html: ChromiumRoute;
        markdown: ChromiumRoute;
    };
    /**
     * Routes for PDF engine operations.
     * @type {Object}
     */
    static readonly PDF_ENGINE_ROUTES: {
        merge: PdfEngineRoute;
        readMetadata: PdfEngineRoute;
        writeMetadata: PdfEngineRoute;
    };
    /**
     * Routes for LibreOffice conversions.
     * @type {Object}
     */
    static readonly LIBRE_OFFICE_ROUTES: {
        convert: LibreOfficeRoute;
    };
    /**
     * Configures the Gotenberg service endpoint and other optional parameters.
     * @param {Object} config - Configuration object.
     * @param {string} config.endpoint - The Gotenberg service endpoint.
     * @param {string} [config.username] - The username for basic authentication.
     * @param {string} [config.password] - The password for basic authentication.
     */
    static configure(config: {
        endpoint: string;
        username?: string;
        password?: string;
    }): void;
    /**
     * Gets the Gotenberg service endpoint.
     * @returns {string}
     */
    static getGotenbergEndpoint(): string;
    /**
     * Gets the username for basic authentication.
     * @returns {string | undefined}
     */
    static getGotenbergApiBasicAuthUsername(): string | undefined;
    /**
     * Gets the password for basic authentication.
     * @returns {string | undefined}
     */
    static getGotenbergApiBasicAuthPassword(): string | undefined;
}
export {};
